==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/qctbentity/QctbJkcxFwtcFwxx.java <==
package cn.gtmap.realestate.supervise.qctbentity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0,2018/2/8
 * @description 房屋套次_房屋信息
 */
@Table(name = "QCTB_JKCX_FWTC_FWXX")
public class QctbJkcxFwtcFwxx implements Serializable {

    /**
     * @author juyulin
     * @description 房屋信息id
     */
    @Id
    private String fwxxid;

    /**
     * @author juyulin
     * @description 查询项目id
     */
    private String cxxmid;

    /**
     * @author juyulin
     * @description 查询编号
     */
    private String cxxmbh;

    /**
     * @author juyulin
     * @description 所属区县
     */
    private String ssqx;

    /**
     * @author juyulin
     * @description 房屋坐落
     */
    private String fwzl;

    /**
     * @author juyulin
     * @description 房屋面积
     */
    private Double fwmj;

    /**
     * @author juyulin
     * @description 规划用途
     */
    private String ghyt;

    /**
     * @author juyulin
     * @description 是否争议
     */
    private String sfzy;

    /**
     * @author juyulin
     * @description 不动产单元号
     */
    private String bdcdyh;

    public String getFwxxid() {
        return fwxxid;
    }

    public void setFwxxid(String fwxxid) {
        this.fwxxid = fwxxid;
    }

    public String getCxxmid() {
        return cxxmid;
    }

    public void setCxxmid(String cxxmid) {
        this.cxxmid = cxxmid;
    }

    public String getCxxmbh() {
        return cxxmbh;
    }

    public void setCxxmbh(String cxxmbh) {
        this.cxxmbh = cxxmbh;
    }

    public String getSsqx() {
        return ssqx;
    }

    public void setSsqx(String ssqx) {
        this.ssqx = ssqx;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getSfzy() {
        return sfzy;
    }

    public void setSfzy(String sfzy) {
        this.sfzy = sfzy;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }


}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/qctbentity/QctbJkcxFwtcFwxx.java <==
package cn.gtmap.realestate.supervise.qctbentity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:juyulin@gtmap.cn">juyulin</a>
 * @version 1.0,2018/2/8
 * @description 房屋套次_房屋信息
 */
@Table(name = "QCTB_JKCX_FWTC_FWXX")
public class QctbJkcxFwtcFwxx implements Serializable {

    /**
     * @author juyulin
     * @description 房屋信息id
     */
    @Id
    private String fwxxid;

    /**
     * @author juyulin
     * @description 查询项目id
     */
    private String cxxmid;

    /**
     * @author juyulin
     * @description 查询编号
     */
    private String cxxmbh;

    /**
     * @author juyulin
     * @description 所属区县
     */
    private String ssqx;

    /**
     * @author juyulin
     * @description 房屋坐落
     */
    private String fwzl;

    /**
     * @author juyulin
     * @description 房屋面积
     */
    private Double fwmj;

    /**
     * @author juyulin
     * @description 规划用途
     */
    private String ghyt;

    /**
     * @author juyulin
     * @description 是否争议
     */
    private String sfzy;

    /**
     * @author juyulin
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author xiejianan
     * @description 权利id
     */
    private String qlid;

    /**
     * @author xiejianan
     * @description bdcddyid
     */
    private String bdcdyid;

    /**
     * @author xiejianan
     * @description 登记时间
     */
    private Date djsj;

    public String getFwxxid() {
        return fwxxid;
    }

    public void setFwxxid(String fwxxid) {
        this.fwxxid = fwxxid;
    }

    public String getCxxmid() {
        return cxxmid;
    }

    public void setCxxmid(String cxxmid) {
        this.cxxmid = cxxmid;
    }

    public String getCxxmbh() {
        return cxxmbh;
    }

    public void setCxxmbh(String cxxmbh) {
        this.cxxmbh = cxxmbh;
    }

    public String getSsqx() {
        return ssqx;
    }

    public void setSsqx(String ssqx) {
        this.ssqx = ssqx;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public Double getFwmj() {
        return fwmj;
    }

    public void setFwmj(Double fwmj) {
        this.fwmj = fwmj;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getSfzy() {
        return sfzy;
    }

    public void setSfzy(String sfzy) {
        this.sfzy = sfzy;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }
}
